# Please keep this package in sync with FC

%global debug_package %{nil}

# Architectures where the tests should pass.
#
# 2020-09: Fails on power64 because qemu TCG does not support all the
#   features required to boot Fedora.
#
# 2020-09: armv7 failed with:
# ./qemu-sanity-check: cannot find a Linux kernel in /boot
#
# 2020-09: aarch64 hangs.
%global test_arches %{s390x} x86_64

Name:            qemu-sanity-check
Version:         1.1.6
Release:         %mkrel 1
Summary:         Simple qemu and Linux kernel sanity checker
Group:		Emulators
License:         GPLv2+

URL:             http://people.redhat.com/~rjones/qemu-sanity-check
Source0:         http://people.redhat.com/~rjones/qemu-sanity-check/files/%{name}-%{version}.tar.gz
Source1:         http://people.redhat.com/~rjones/qemu-sanity-check/files/%{name}-%{version}.tar.gz.sig
# Keyring used to verify tarball signature.
Source2:        libguestfs.keyring

Patch100: qemu-sanity-check-mga.patch

# To verify the tarball signature.
BuildRequires:  gnupg2

BuildRequires:   gcc

# For building manual pages.
BuildRequires:   perl-doc

# For building the initramfs.
BuildRequires:   cpio
BuildRequires:   glibc-static-devel

# For testing.
BuildRequires:   qemu
BuildRequires:   kernel

%ifarch %{ix86} x86_64
Requires:        qemu-system-x86
%global qemu     %{_bindir}/qemu-system-x86_64
%endif
%ifarch armv7hl
Requires:        qemu-system-arm
%global qemu     %{_bindir}/qemu-system-arm
%endif
%ifarch aarch64
Requires:        qemu-system-aarch64
%global qemu     %{_bindir}/qemu-system-aarch64
%endif
%ifarch %{power64}
Requires:        qemu-system-ppc
%global qemu     %{_bindir}/qemu-system-ppc64
%endif
%ifarch %{s390x}
Requires:        qemu-system-s390x
%global qemu     %{_bindir}/qemu-system-s390x
%endif

Requires:        kernel

# Require the -nodeps subpackage.
Requires:        %{name}-nodeps = %{version}-%{release}


%description
Qemu-sanity-check is a short shell script that test-boots a Linux
kernel under qemu, making sure it boots up to userspace.  The idea is
to test the Linux kernel and/or qemu to make sure they are working.

Most users should install the %{name} package.

If you are testing qemu or the kernel in those packages and you want
to avoid a circular dependency on qemu or kernel, you should use
'BuildRequires: %{name}-nodeps' instead.


%package nodeps
Summary:         Simple qemu and Linux kernel sanity checker (no dependencies)
License:         GPLv2+


%description nodeps
This is the no-depedencies version of %{name}.  It is exactly the same
as %{name} except that this package does not depend on qemu or kernel.


%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -p1


%build
# NB: canonical_arch is a variable in the final script, so it
# has to be escaped here.
%configure \
%if 0%{?qemu:1}
    --with-qemu-list="%{qemu}" \
%else
    --with-qemu-list="qemu-system-\$canonical_arch" \
%endif
|| {
  cat config.log
  exit 1
}
%make_build


%check
%ifarch %{test_arches}
make check || {
  cat test-suite.log
  exit 0
}
%endif


%install
make DESTDIR=$RPM_BUILD_ROOT install


%files
%doc COPYING


%files nodeps
%doc COPYING README
%{_bindir}/qemu-sanity-check
%{_libdir}/qemu-sanity-check
%{_mandir}/man1/qemu-sanity-check.1*




%changelog
* Sat Sep 12 2020 tv <tv> 1.1.6-1.mga8
+ Revision: 1624998
- New upstream version 1.1.6.
- Remove all patches.
- Run the tests on some more arches.
- Require qemu-system-<arch>.
- Enable hardened build.
- Enable signed tarball.
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 1.1.5-2.mga7
+ Revision: 1300644
- Mageia 7 Mass Rebuild

* Mon Mar 26 2018 tv <tv> 1.1.5-1.mga7
+ Revision: 1212671
- imported package qemu-sanity-check

